'use strict';
var yeoman = require('yeoman-generator');
var chalk = require('chalk');
var yosay = require('yosay');

module.exports = yeoman.generators.Base.extend({
	initializing: function () {
		this.pkg = require('../package.json');
	},

	prompting: {
		basicPrompting: function () {
			var done = this.async();

			// Have Yeoman greet the user.
			this.log(yosay(
				'Welcome to the ' + chalk.red('Testdrivedemo') + ' generator!'
			));

			var prompts = [{
				type: 'input',
				name: 'name',
				message: 'What is the name of your demo? e.g. "ES6 Generators"',
				default: 'Demo name',
				store: true,
				required: true
			}, {
				type: 'list',
				name: 'category',
				message: 'In which category does it fit?',
				choices: ['Input', 'Graphics', 'Media', 'Performance', 'CSS', 'JavaScript', 'Misc'],
				store: true,
				required: true
			}, {
				type: 'input',
				name: 'title',
				message: 'Explain in a phrase the goal of the demo. e.g. "Lear how to use the ECMAScript 6 Generators"',
				default: 'title',
				store: true
			}, {
				type: 'input',
				name: 'keywords',
				message: 'Some keywords comma separated? e.g. "generators, es6, ecmascript"',
				default: '',
				store: true,
				required: true
			}, {
				type: 'input',
				name: 'author',
				message: 'Whats your name (or GitHub user)?',
				default: 'InternetExplorer',
				store: true,
				required: true
			}, {
				type: 'input',
				name: 'description',
				message: 'Do you want to provide a longer description for the demo?',
				default: '',
				store: true,
				required: true
			}, {
				type: 'list',
				name: 'template',
				message: 'What type of template do you need?',
				choices: ['Minimal', 'Basic with default styles', 'Complex with jQuery included'],
				store: true,
				required: true,
				filter: function (val) {
					return val.toLowerCase().split(' ')[0];
				}
			}];

			this.prompt(prompts, function (props) {
				this.answers = {
					name: props.name,
					category: props.category,
					title: props.title,
					keywords: props.keywords,
					author: props.author,
					description: props.description,
					template: props.template
				};

				console.log('Template: ' + props.template);
				done();
			}.bind(this));
		}
	},
	writing: {
		app: function () {
			this.fs.copy(
				this.templatePath('.eslintrc'),
				this.destinationPath('.eslintrc'));
			this.fs.copy(
				this.templatePath('.jscsrc'),
				this.destinationPath('.jscsrc'));
			this.fs.copy(
				this.templatePath('.csslintrc'),
				this.destinationPath('.csslintrc'));
			this.fs.copy(
				this.templatePath('.editorconfig'),
				this.destinationPath('.editorconfig'));
			this.fs.copy(
				this.templatePath('styles/demo.css'),
				this.destinationPath('styles/demo.css'));
			this.fs.copy(
				this.templatePath('images/ie-avatar.png'),
				this.destinationPath('images/ie-avatar.png'));

			if (this.answers.template === 'minimal') {
				this.fs.copy(
					this.templatePath('scripts/demo-basic.js'),
					this.destinationPath('scripts/demo.js'));
				this.answers.template = '';
			} else {
				this.fs.copy(
					this.templatePath('styles/demotemplate.css'),
					this.destinationPath('styles/demotemplate.css'));
				if (this.answers.template === 'complex') {
					this.fs.copy(
						this.templatePath('scripts/demo-complex.js'),
						this.destinationPath('scripts/demo.js'));
				} else if (this.answers.template === 'basic') {
					this.fs.copy(
						this.templatePath('scripts/demo-basic.js'),
						this.destinationPath('scripts/demo.js'));
				}
			}

			this.fs.copyTpl(
				this.templatePath('index-' + this.answers.template + '.html'),
				this.destinationPath('index.html'), this.answers);
		}
	}
});
